translate.storage.properties.DialectFlex

Package translate :: Package storage :: Module properties :: Class DialectFlex |
[hide private]
[frames] | no frames]

# Class DialectFlex

source code

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `Dialect`: `encode`, `find_delimiter`, `key_strip`, `value_strip`

Class Variables | [hide private]
| name = `"flex"` hash(x)
| default_encoding = `"utf-8"`
Inherited from `DialectJava`: `delimiters` Inherited from `Dialect`: `drop_comments`, `key_wrap_char`, `pair_terminator`, `value_wrap_char`

Properties | [hide private]
Inherited from `object`: `__class__`